==> simple_bar_graph-0.1.0.tar.gz: lib/graph_controller.dart <==
import 'package:flutter/widgets.dart';
import 'models.dart';

class DataSelection<T> {
  DataSelection(this.group, this.dataItem);

  final DataGroup<T> group;
  final DataItem dataItem;
}

/// The `GraphController` holds data to be drawn on the graph. It also notifies
/// listeners on selection change. At least one group of data is required to draw
/// the graph.
class GraphController<T> extends ValueNotifier<DataSelection<T>> {
  /// Data groups to be plotted. The graph should contain at least one group.
  List<DataGroup<T>> groups;

  DataItem maxValue;

  GraphController(this.groups) : super(null);

  /// This should be called right before it is passed to a [SimpleBarGraph].
  /// It makes a default selection to the last item in the combined groups data and sets
  /// the maximum value of all data combined.
  ///
  /// If this behaviour is not intended, you can manually use [select] to set your
  /// custom default.
  void initialize() {
    this.value = DataSelection(this.groups.last, this.groups.last.data.last);

    final _chart = <DataItem>[];

    this.groups.forEach((_group) {
      _chart.addAll(_group.data);
    });

    maxValue = _chart.reduce((v1, v2) {
      return v1.value > v2.value ? v1 : v2;
    });
  }

  void select(DataItem dataItem) {
    final containerGroup = this.groups.firstWhere((dg) {
      return dg.data.contains(dataItem);
    });

    this.value = DataSelection(containerGroup, dataItem);
  }

  /// Returns the group in which [data] belongs to
  DataGroup getBelongingGroup(DataItem data) {
    return groups.firstWhere((it) {
      return it.data.contains(data);
    });
  }

  bool isActive(DataItem dataItem) {
    return this.value.group.data.contains(dataItem);
  }
}

==> simple_bar_graph-0.1.2.tar.gz: lib/graph_controller.dart <==
import 'package:flutter/widgets.dart';

import 'models.dart';

class DataSelection<T> {
  DataSelection(this.group, this.dataItem);

  final DataGroup<T> group;
  final DataItem dataItem;
}

/// The `GraphController` holds data to be drawn on the graph. It also notifies
/// listeners on selection change. At least one group of data is required to draw
/// the graph.
class GraphController<T> extends ValueNotifier<DataSelection<T>> {
  /// Data groups to be plotted. The graph should contain at least one group.
  List<DataGroup<T>> groups;

  DataItem maxValue;

  GraphController([this.groups]) : super(null);

  /// This should be called right before it is passed to a [SimpleBarGraph].
  /// It makes a default selection to the last item in the combined groups data and sets
  /// the maximum value of all data combined.
  ///
  /// If this behaviour is not intended, you can manually use [select] to set your
  /// custom default.
  void initialize() {
    if (groups != null) {
      this.value = DataSelection(this.groups.last, this.groups.last.data.last);

      final _chart = <DataItem>[];

      this.groups.forEach((_group) {
        _chart.addAll(_group.data);
      });

      maxValue = _chart.reduce((v1, v2) {
        return v1.value > v2.value ? v1 : v2;
      });
    }
  }

  void select(DataItem dataItem) {
    final containerGroup = this.groups.firstWhere((dg) {
      return dg.data.contains(dataItem);
    });

    this.value = DataSelection(containerGroup, dataItem);
  }

  /// Returns the group in which [data] belongs to
  DataGroup getBelongingGroup(DataItem data) {
    return groups.firstWhere((it) {
      return it.data.contains(data);
    });
  }

  bool isActive(DataItem dataItem) {
    return this.value.group.data.contains(dataItem);
  }
}
